package com.gic.cloud.web.controller;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSON;
import com.gic.cloud.web.auth.DataAuthUtils;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.data.api.qo.consumestructure.*;
import com.gic.data.api.service.consumestructure.ConsumeStructureApiService;
import com.gic.enterprise.utils.ResultControllerUtils;

@RestController
public class ConsumeStructureController {
    private static final Logger log = LogManager.getLogger(ConsumeStructureController.class);
    @Autowired
    private ConsumeStructureApiService consumeStructureApiService;
    @Autowired
    private StoreSearchUtils storeSearchUtils;
    @Autowired
    private DataAuthUtils dataAuthUtils;

    /**
     * 年龄消费占比（订单人数/订单数/销售额）
     * @Title: queryAgeConsumeShare 
     * @Description:
     * @author guojuxing
     * @param params 
     * @return  com.gic.commons.webapi.reponse.RestResponse 
     */
    @RequestMapping("get-age-consume-share")
    public RestResponse queryAgeConsumeShare(AgeConsumeShareQO params) {
        log.info("消费构成-消费年龄-年龄消费占比参数：{}", JSON.toJSONString(params));
        params.setOnlineStoreIdList(storeSearchUtils.onLineStoreSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        params.setStoreInfoIdList(storeSearchUtils.storeSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        return ResultControllerUtils.commonResult(consumeStructureApiService.queryAgeConsumeShare(params));
    }

    @RequestMapping("get-age-consume-survey")
    public RestResponse queryAgeConsumeSurvey(AgeConsumeShareQO params) {
        log.info("消费构成-消费年龄-概况参数：{}", JSON.toJSONString(params));
        params.setOnlineStoreIdList(storeSearchUtils.onLineStoreSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        params.setStoreInfoIdList(storeSearchUtils.storeSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        return ResultControllerUtils.commonResult(consumeStructureApiService.queryAgeConsumeSurvey(params));
    }

    @RequestMapping("get-age-consume-area")
    public RestResponse queryAgeConsumeArea(AgeConsumeAreaQO params) {
        log.info("消费构成-消费年龄-区域参数：{}", JSON.toJSONString(params));
        params.setOnlineStoreIdList(storeSearchUtils.onLineStoreSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        params.setStoreInfoIdList(storeSearchUtils.storeSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        if (params.getLevel() != null) {
            params.setLevel(storeSearchUtils.getLevel(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()).getLevel());
        }
        params.setGroupIdList(storeSearchUtils.getChildrenStoreGroupIdList(params.getParentId()));
        params.setMemberCardIdList(dataAuthUtils.getMbrAreaId(params.getUserId(), params.getEnterpriseId()));
        return ResultControllerUtils.commonResult(consumeStructureApiService.pageAgeConsumeArea(params));
    }

    @RequestMapping("get-grade-consume-trend")
    public RestResponse getGradeConsumeTrend(GradeConsumeTrendQO params) {
        log.info("消费构成-等级-趋势参数：{}", JSON.toJSONString(params));
        params.setOnlineStoreIdList(storeSearchUtils.onLineStoreSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        params.setStoreInfoIdList(storeSearchUtils.storeSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        return ResultControllerUtils.commonResult(consumeStructureApiService.queryGradeConsumeTrend(params));
    }

    @RequestMapping("get-grade-consume-survey")
    public RestResponse getGradeConsumeSurvey(GradeConsumeTrendQO params) {
        log.info("消费构成-等级-概况参数：{}", JSON.toJSONString(params));
        params.setOnlineStoreIdList(storeSearchUtils.onLineStoreSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        params.setStoreInfoIdList(storeSearchUtils.storeSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        return ResultControllerUtils.commonResult(consumeStructureApiService.queryGradeConsumeSurvey(params));
    }

    @RequestMapping("get-grade-consume-area")
    public RestResponse queryGradeConsumeArea(GradeConsumeAreaQO params) {
        log.info("消费构成-等级-区域参数：{}", JSON.toJSONString(params));
        params.setOnlineStoreIdList(storeSearchUtils.onLineStoreSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        params.setStoreInfoIdList(storeSearchUtils.storeSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        if (params.getLevel() != null) {
            params.setLevel(storeSearchUtils.getLevel(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()).getLevel());
        }
        params.setGroupIdList(storeSearchUtils.getChildrenStoreGroupIdList(params.getParentId()));
        return ResultControllerUtils.commonResult(consumeStructureApiService.pageGradeConsumeArea(params));
    }

    @RequestMapping("get-birth-consume-rate")
    public RestResponse getBirthConsumeRate(BirthConsumeRateQO params) {
        log.info("消费构成-生日会员-占比参数：{}", JSON.toJSONString(params));
        params.setOnlineStoreIdList(storeSearchUtils.onLineStoreSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        params.setStoreInfoIdList(storeSearchUtils.storeSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        params.setMemberCardIdList(dataAuthUtils.getMbrAreaId(params.getUserId(), params.getEnterpriseId()));
        return ResultControllerUtils.commonResult(consumeStructureApiService.getBirthConsumeRate(params));
    }

    @RequestMapping("get-birth-consume-trend")
    public RestResponse getBirthConsumeTrend(BirthConsumeRateQO params) {
        log.info("消费构成-生日会员-趋势参数：{}", JSON.toJSONString(params));
        params.setOnlineStoreIdList(storeSearchUtils.onLineStoreSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        params.setStoreInfoIdList(storeSearchUtils.storeSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        params.setMemberCardIdList(dataAuthUtils.getMbrAreaId(params.getUserId(), params.getEnterpriseId()));
        return ResultControllerUtils.commonResult(consumeStructureApiService.queryBirthConsumeTrend(params));
    }

    @RequestMapping("get-birth-consume-survey")
    public RestResponse getBirthConsumeSurvey(BirthConsumeRateQO params) {
        log.info("消费构成-生日会员-概况参数：{}", JSON.toJSONString(params));
        params.setOnlineStoreIdList(storeSearchUtils.onLineStoreSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        params.setStoreInfoIdList(storeSearchUtils.storeSearch(params.getUserId(), params.getEnterpriseId(), params.getSearchJson()));
        params.setMemberCardIdList(dataAuthUtils.getMbrAreaId(params.getUserId(), params.getEnterpriseId()));
        return ResultControllerUtils.commonResult(consumeStructureApiService.queryBirthConsumeSurvey(params));
    }
}
