package com.gic.cloud.web.controller;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.cloud.dto.FunctionDTO;
import com.gic.cloud.dto.FunctionModuleDTO;
import com.gic.cloud.service.FunctionApiService;
import com.gic.cloud.service.FunctionModuleApiService;
import com.gic.cloud.service.IndexApiService;
import com.gic.cloud.web.auth.DataAuthUtils;
import com.gic.cloud.web.qo.DateTypeQo;
import com.gic.cloud.web.vo.FunctionModuleVo;
import com.gic.cloud.web.vo.LevelNameVo;
import com.gic.cloud.web.vo.LevelVo;
import com.gic.cloud.web.vo.MbrVo;
import com.gic.cloud.web.vo.index.IndexSalesVo;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.data.api.dto.IndexSalesDTO;
import com.gic.data.api.service.IndexSalesApiService;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;

@RestController
public class IndexController {
    @Autowired
    private IndexSalesApiService indexSalesApiService;
    @Autowired
    private StoreSearchUtils storeSearchUtils;
    @Autowired
    private DataAuthUtils dataAuthUtils;
    @Autowired
    private FunctionApiService functionApiService;

    @RequestMapping("index-mbr")
    public RestResponse indexMbr(Integer enterpriseId, Integer userId){
        List<MbrVo> mbrArea = this.dataAuthUtils.getMbrArea(userId, enterpriseId);
        return RestResponse.success(mbrArea);
    }

    @RequestMapping("index-sales")
    public RestResponse indexSales(Integer userId, Integer enterpriseId, String searchJSON,
                                   DateTypeQo dateTypeQo, String mbrAreaId, Integer dataType){
        List<Integer> list = this.storeSearchUtils.storeSearch(userId, enterpriseId, searchJSON);
        List<String> onLine = this.storeSearchUtils.onLineStoreSearch(userId, enterpriseId, searchJSON);
        ServiceResponse<IndexSalesDTO> indexSales = this.indexSalesApiService.getIndexSales(enterpriseId, list, onLine,
                StringUtils.isNoneBlank(mbrAreaId) ? Long.valueOf(mbrAreaId) : null, dateTypeQo.getType(), dateTypeQo.getDate(), dataType);
        return RestResponse.success(EntityUtil.changeEntityByJSON(IndexSalesVo.class, indexSales.getResult()));
    }


    @RequestMapping("function-list")
    public RestResponse functionList(Integer userId){
        ServiceResponse<List<FunctionModuleDTO>> response = this.functionApiService.getFunctionByUserId(userId);
        List<FunctionModuleVo> list = new ArrayList<>();
        if(response.isSuccess() && CollectionUtils.isNotEmpty(response.getResult())){
            for(FunctionModuleDTO dto : response.getResult()){
                if(dto != null){
                    list.add(EntityUtil.changeEntityByJSON(FunctionModuleVo.class, dto));
                }
            }
        }
        return RestResponse.success(list);
    }

    @RequestMapping("get-level")
    public RestResponse getLevel(Integer userId, Integer enterpriseId, String searchJSON){
        LevelVo level = this.storeSearchUtils.getLevel(userId, enterpriseId, searchJSON);
        List<LevelNameVo> list = new ArrayList<>();
        LevelNameVo vo0 = new LevelNameVo(0, "所有渠道", 0 >= level.getLevel() && 0 <= level.getMaxLevel() ? 1: 0);
        LevelNameVo vo1 = new LevelNameVo(1, "第一层级", 1 >= level.getLevel() && 1 <= level.getMaxLevel() ? 1: 0);
        LevelNameVo vo2 = new LevelNameVo(2, "第二层级", 2 >= level.getLevel() && 2 <= level.getMaxLevel() ? 1: 0);
        LevelNameVo vo3 = new LevelNameVo(3, "第三层级", 3 >= level.getLevel() && 3 <= level.getMaxLevel() ? 1: 0);
        LevelNameVo vo4 = new LevelNameVo(4, "第四层级", 4 >= level.getLevel() && 4 <= level.getMaxLevel() ? 1: 0);
        LevelNameVo vo5 = new LevelNameVo(5, "第五层级", 5 >= level.getLevel() && 5 <= level.getMaxLevel() ? 1: 0);
        LevelNameVo vo6 = new LevelNameVo(6, "第六层级", 6 >= level.getLevel() && 6 <= level.getMaxLevel() ? 1: 0);
        LevelNameVo vo7 = new LevelNameVo(7, "门店", 1);
        LevelNameVo vo8 = new LevelNameVo(8, "导购", 1);
        list.add(vo0);
        list.add(vo1);
        list.add(vo2);
        list.add(vo3);
        list.add(vo4);
        list.add(vo5);
        list.add(vo6);
        list.add(vo7);
        list.add(vo8);
        return RestResponse.success(list);
    }

}
